==> seamonkey-2.53.7.1.source.tar.xz: seamonkey-2.53.7.1/devtools/server/tests/unit/test_profiler_events-02.js <==
/* Any copyright is dedicated to the Public Domain.
   http://creativecommons.org/publicdomain/zero/1.0/ */

"use strict";

/**
 * Tests the event notification service for the profiler actor.
 */

const Profiler = Cc["@mozilla.org/tools/profiler;1"].getService(Ci.nsIProfiler);
const MAX_PROFILER_ENTRIES = 10000000;
const { ProfilerFront } = require("devtools/shared/fronts/profiler");
const { waitForTime } = DevToolsUtils;

add_task(function* () {
  let [client, form] = yield getChromeActors();
  let front = new ProfilerFront(client, form);

  // Ensure the profiler is not running when the test starts (it could
  // happen if the MOZ_PROFILER_STARTUP environment variable is set).
  Profiler.StopProfiler();
  let eventsCalled = 0;
  let handledThreeTimes = promise.defer();

  front.on("profiler-status", (response) => {
    dump("'profiler-status' fired\n");
    Assert.ok(typeof response.position === "number");
    Assert.ok(typeof response.totalSize === "number");
    Assert.ok(typeof response.generation === "number");
    Assert.ok(response.position > 0 && response.position < response.totalSize);
    Assert.ok(response.totalSize === MAX_PROFILER_ENTRIES);
    // There's no way we'll fill the buffer in this test.
    Assert.ok(response.generation === 0);

    eventsCalled++;
    if (eventsCalled > 2) {
      handledThreeTimes.resolve();
    }
  });

  yield front.setProfilerStatusInterval(1);
  dump("Set the profiler-status event interval to 1\n");
  yield front.startProfiler();
  yield waitForTime(500);
  yield front.stopProfiler();

  Assert.ok(eventsCalled === 0,
                "No 'profiler-status' events should be fired before registering.");

  let ret = yield front.registerEventNotifications({ events: ["profiler-status"] });
  Assert.ok(ret.registered.length === 1);

  yield front.startProfiler();
  yield handledThreeTimes.promise;
  yield front.stopProfiler();
  Assert.ok(eventsCalled >= 3,
                "profiler-status fired atleast three times while recording");

  let totalEvents = eventsCalled;
  yield waitForTime(50);
  Assert.ok(totalEvents === eventsCalled,
                "No more profiler-status events after recording.");
});

function getChromeActors() {
  let deferred = promise.defer();
  get_chrome_actors((client, form) => deferred.resolve([client, form]));
  return deferred.promise;
}

==> seamonkey-2.53.8.source.tar.xz: seamonkey-2.53.8/devtools/server/tests/unit/test_profiler_events-02.js <==
/* Any copyright is dedicated to the Public Domain.
   http://creativecommons.org/publicdomain/zero/1.0/ */

"use strict";

/**
 * Tests the event notification service for the profiler actor.
 */

const Profiler = Cc["@mozilla.org/tools/profiler;1"].getService(Ci.nsIProfiler);
const MAX_PROFILER_ENTRIES = 10000000;
const { ProfilerFront } = require("devtools/shared/fronts/profiler");
const { waitForTime } = DevToolsUtils;

add_task(function* () {
  let [client, form] = yield getChromeActors();
  let front = new ProfilerFront(client, form);

  // Ensure the profiler is not running when the test starts (it could
  // happen if the MOZ_PROFILER_STARTUP environment variable is set).
  Profiler.StopProfiler();
  let eventsCalled = 0;
  let handledThreeTimes = defer();

  front.on("profiler-status", (response) => {
    dump("'profiler-status' fired\n");
    Assert.ok(typeof response.position === "number");
    Assert.ok(typeof response.totalSize === "number");
    Assert.ok(typeof response.generation === "number");
    Assert.ok(response.position > 0 && response.position < response.totalSize);
    Assert.ok(response.totalSize === MAX_PROFILER_ENTRIES);
    // There's no way we'll fill the buffer in this test.
    Assert.ok(response.generation === 0);

    eventsCalled++;
    if (eventsCalled > 2) {
      handledThreeTimes.resolve();
    }
  });

  yield front.setProfilerStatusInterval(1);
  dump("Set the profiler-status event interval to 1\n");
  yield front.startProfiler();
  yield waitForTime(500);
  yield front.stopProfiler();

  Assert.ok(eventsCalled === 0,
                "No 'profiler-status' events should be fired before registering.");

  let ret = yield front.registerEventNotifications({ events: ["profiler-status"] });
  Assert.ok(ret.registered.length === 1);

  yield front.startProfiler();
  yield handledThreeTimes.promise;
  yield front.stopProfiler();
  Assert.ok(eventsCalled >= 3,
                "profiler-status fired atleast three times while recording");

  let totalEvents = eventsCalled;
  yield waitForTime(50);
  Assert.ok(totalEvents === eventsCalled,
                "No more profiler-status events after recording.");
});

function getChromeActors() {
  let deferred = defer();
  get_chrome_actors((client, form) => deferred.resolve([client, form]));
  return deferred.promise;
}
